@@ -1,4 +1,4 @@
-__version__ = "0.4.1"
+__version__ = "0.4.3"
 
 from .io import yaml_load, yaml_dump, save, load, json_load, json_dump
 from .path import *
@@ -8,7 +8,7 @@ from .async_api import ConcurrentRequester
 from .nlp.parser import parse_to_obj, parse_to_code
 from .ai_platform.metrics import MetricsCalculator, save_pred_metrics
 from .llm.openaiclient import OpenAIClient
-from .vllm.client.image_processor import encode_to_base64, decode_base64_to_pil
+from .vllm.client.image_processor_helper import ImageProcessor
 # from .decorators import benchmark
 # from .string.color_string import rgb_string
 # from .functions.core import clamp, topk, dict_topk
